diff --git a/Ghidra/Features/Decompiler/build.gradle b/Ghidra/Features/Decompiler/build.gradle
index eba71e4..5fc1d1f 100755
--- a/Ghidra/Features/Decompiler/build.gradle
+++ b/Ghidra/Features/Decompiler/build.gradle
@@ -97,6 +97,9 @@ model {
 		                include "prefersplit.cc"
 		                include "rangeutil.cc"
 		                include "ruleaction.cc"
+		                include "rulecompile.cc"
+		                include "ruleparse.cc"
+		                include "unify.cc"
 		                include "subflow.cc"
 		                include "transform.cc"
 		                include "blockaction.cc"
@@ -205,6 +208,8 @@ model {
 			binaries {
 				all{ b ->
 					b.cppCompiler.define "LOCAL_ZLIB"
+                    b.cppCompiler.define "CPUI_RULECOMPILE"
+                    b.cCompiler.define "CPUI_RULECOMPILE"
 					b.cCompiler.define "NO_GZIP"
 				}
 			} // end binaries.all (sleigh)
@@ -214,6 +219,8 @@ model {
 	
 	binaries {
 		all{ b ->
+            b.cppCompiler.define "CPUI_RULECOMPILE"
+            b.cCompiler.define "CPUI_RULECOMPILE"
 			if (b.toolChain in Gcc) {
 				b.cppCompiler.args "-std=c++11"
 				b.cppCompiler.args "-Wall"
diff --git a/Ghidra/Features/Decompiler/src/decompile/cpp/architecture.cc b/Ghidra/Features/Decompiler/src/decompile/cpp/architecture.cc
index 494d160..8ac2725 100755
--- a/Ghidra/Features/Decompiler/src/decompile/cpp/architecture.cc
+++ b/Ghidra/Features/Decompiler/src/decompile/cpp/architecture.cc
@@ -726,7 +726,7 @@ void Architecture::decodeDynamicRule(Decoder &decoder)
     throw LowlevelError("Dynamic rule has no group");
   if (!enabled) return;
 #ifdef CPUI_RULECOMPILE
-  Rule *dynrule = RuleGeneric::build(rulename,groupname,el->getContent());
+  Rule *dynrule = RuleGeneric::build(rulename,groupname, (reinterpret_cast<XmlDecode*>(&decoder))->getCurrentXmlElement()->getContent());
   extra_pool_rules.push_back(dynrule);
 #else
   throw LowlevelError("Dynamic rules have not been enabled for this decompiler");
diff --git a/Ghidra/Features/Decompiler/src/decompile/cpp/ghidra_process.cc b/Ghidra/Features/Decompiler/src/decompile/cpp/ghidra_process.cc
index 9ec6788..3420b63 100755
--- a/Ghidra/Features/Decompiler/src/decompile/cpp/ghidra_process.cc
+++ b/Ghidra/Features/Decompiler/src/decompile/cpp/ghidra_process.cc
@@ -191,6 +191,8 @@ void RegisterProgram::rawAction(void)
   corespec.clear();
 
   DocumentStorage store;	// temp storage of initialization xml docs
+  Element *root = store.openDocument("/etc/ghidra-rules.xml")->getRoot();
+  store.registerTag(root);
   ghidra->init(store);
   if (open == -1) {
     open = archlist.size();
diff --git a/Ghidra/Features/Decompiler/src/decompile/cpp/rulecompile.cc b/Ghidra/Features/Decompiler/src/decompile/cpp/rulecompile.cc
index fe8a413..743b32b 100755
--- a/Ghidra/Features/Decompiler/src/decompile/cpp/rulecompile.cc
+++ b/Ghidra/Features/Decompiler/src/decompile/cpp/rulecompile.cc
@@ -14,14 +14,21 @@
  * limitations under the License.
  */
 #ifdef CPUI_RULECOMPILE
+
+#include "types.h"
+#include <string>
+using std::string;
+using namespace ghidra;
+
 #include "rulecompile.hh"
 #include "ruleparse.hh"
 
+int4 ruleparsedebug;
+extern int4 ruleparseparse(void);
+
 namespace ghidra {
 
 RuleCompile *rulecompile;
-extern int4 ruleparsedebug;
-extern int4 ruleparseparse(void);
 
 class MyLoadImage : public LoadImage { // Dummy loadimage
 public:
diff --git a/Ghidra/Features/Decompiler/src/decompile/cpp/ruleparse.y b/Ghidra/Features/Decompiler/src/decompile/cpp/ruleparse.y
index 3d3ced6..32f42ff 100755
--- a/Ghidra/Features/Decompiler/src/decompile/cpp/ruleparse.y
+++ b/Ghidra/Features/Decompiler/src/decompile/cpp/ruleparse.y
@@ -15,11 +15,19 @@
  */
 %{
 #ifdef CPUI_RULECOMPILE
+
+#include "types.h"
+#include <string>
+using std::string;
+
 #include "rulecompile.hh"
 
 #define YYERROR_VERBOSE
 
+using namespace ghidra;
+namespace ghidra {
 extern RuleCompile *rulecompile;
+}
 extern int ruleparselex(void);
 extern int ruleparseerror(const char *str);
 
